import { ShowMessageLinkActionType } from 'totvs-log-base-foundation';
import { PoModalComponent } from '@portinari/portinari-ui';
import { Component, ViewChild } from '@angular/core';

/**
 * Classe/componente de mensagem
 */
@Component({
    selector: 'lib-message',
    templateUrl: './message.component.html',
    styleUrls: ['./message.component.css']
})
export class MessageComponent {

    /**
     * Atributo que recebe a referência do componente PoModalComponent no HTML
     */
    @ViewChild(PoModalComponent, {static: true}) poModal: PoModalComponent;

    /**
     * Atributo com o título da mensagem
     */
    messageTitle = '';

    /**
     * Atributo com o texto da mensagem
     */
    messageText = '';

    /**
     * Atributo com os detalhes da mensagem
     */
    messageDetails = '';

    /**
     * Atributo que recebe a ação de confirmação
     */
    messageConfirmAction = undefined;

    /**
     * Atributo que recebe a ação de cancelamento
     */
    messageCancelAction = undefined;

    /**
     * Atributo que recebe o tipo do link
     */
    messageLinkActionType = ShowMessageLinkActionType.No;

    /**
     * Atributo que recebe o link
     */
    messageLinkAction = undefined;

    /**
     * Atributo que recebe o label do link
     */
    messageLinkLabel = '';

    /**
     * Atributo que indica se os detalhes da mensagem devem ser escondidos
     */
    hideDetails = true;

    /**
     * Método responsável por disparar a abertura da dialog
     */
    public openDialog() {
        this.poModal.open();
    }

    /**
     * Método responsável por fechar a dialog
     */
    public closeDialog() {
        this.poModal.close();
    }

    /**
     * Método responsável por executar ação do link relacionado a mensagem
     */
    public linkAction() {

        this.messageLinkAction();
    }
}
